@@ -1,7 +1,7 @@
 package Acme::MyFirstModule::AUSTIN;
 
 use 5.006;
-use LOL
+use strict;
 use warnings FATAL => 'all';
 
 =head1 NAME
@@ -10,11 +10,11 @@ Acme::MyFirstModule::AUSTIN - The great new Acme::MyFirstModule::AUSTIN!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
